package net.sf.basedb.examples.extensions.menu;

import net.sf.basedb.clients.web.extensions.AbstractJspActionFactory;
import net.sf.basedb.clients.web.extensions.menu.MenuItemAction;
import net.sf.basedb.clients.web.extensions.menu.MenuItemBean;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.SessionControl;
import net.sf.basedb.core.User;
import net.sf.basedb.util.extensions.ClientContext;
import net.sf.basedb.util.extensions.InvokationContext;
import net.sf.basedb.util.extensions.xml.PathSetter;
import net.sf.basedb.util.extensions.xml.VariableSetter;

/**
	Example menu item factory that creates a "Hello world" menu item
	where the "Hello" part can be changed by the "prefix" setting in the
	XML file, and the "world" part is dynamically replaced with the name
	of the logged in user.
	
	@author nicklas
*/
public class HelloUserFactory 
	extends AbstractJspActionFactory<MenuItemAction>
{
	// To store the URL to the icon
	private String icon;
	
	// The default prefix is Hello
	private String prefix = "Hello";
	
	// A public, no-argument constructor is required
	public HelloUserFactory()
	{}
	
	/**
		Creates a menu item that displays: {prefix} {name of user}!
	*/
	public MenuItemAction[] getActions(InvokationContext<? super MenuItemAction> context) 
	{
		String userName = getUserName(context.getClientContext());
		MenuItemBean helloUser = new MenuItemBean();
		helloUser.setMenuId("hello");
		helloUser.setTitle(prefix + " " + userName + "!");
		helloUser.setIcon(icon);
		helloUser.setOnClick("alert('" + prefix + " " + userName + "!')");
		return new MenuItemAction[] { helloUser };
	}

	/**
		Get the name of the logged in user.
	*/
	private String getUserName(ClientContext context)
	{
		SessionControl sc = context.getSessionControl();
		DbControl dc = context.getDbControl();
		User current = User.getById(dc, sc.getLoggedInUserId());
		return current.getName();
	}
	
	/**
		Sets the icon to use. Path conversion is enabled.
	*/
	@VariableSetter
	@PathSetter
	public void setIcon(String icon)
	{
		this.icon = icon;
	}
	
	/**
		Sets the prefix to use. If not set, the
		default value is "Hello".
	*/
	public void setPrefix(String prefix)
	{
		this.prefix = prefix == null ? "Hello" : prefix;
	}
}
